=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2012-07-19 15:34:45 +0000
+++ bzrlib/branch.py	2012-07-19 15:44:55 +0000
@@ -252,10 +252,6 @@
         """
         raise NotImplementedError(self._get_config)
 
-    def has_stored_uncommitted(self):
-        """If true, the branch has stored, uncommitted changes in it."""
-        raise NotImplementedError(self.has_stored_uncommitted)
-
     def store_uncommitted(self, creator, message=None):
         """Store uncommitted changes from a ShelfCreator.
 
@@ -2443,10 +2439,6 @@
         else:
             return self
 
-    def has_stored_uncommitted(self):
-        """If true, the branch has stored, uncommitted changes in it."""
-        return self._uncommitted_branch()._get_uncommitted() is not None
-
     def store_uncommitted(self, creator, message=None):
         """Store uncommitted changes from a ShelfCreator.
 
@@ -2459,7 +2451,7 @@
         if creator is None:
             branch._put_uncommitted(None)
             return
-        if branch.has_stored_uncommitted():
+        if branch._get_uncommitted() is not None:
             raise errors.ChangesAlreadyStored
         transform = StringIO()
         creator.write_shelf(transform, message)

=== modified file 'bzrlib/tests/per_branch/test_branch.py'
--- bzrlib/tests/per_branch/test_branch.py	2012-07-19 15:34:45 +0000
+++ bzrlib/tests/per_branch/test_branch.py	2012-07-19 15:44:55 +0000
@@ -1083,14 +1083,6 @@
         # Setting uncommitted to None when it is already None is not an error.
         branch._put_uncommitted(None)
 
-    def test_has_stored_uncommitted(self):
-        branch = self.make_branch('b')
-        self.assertFalse(branch.has_stored_uncommitted())
-        branch._put_uncommitted(StringIO('hello'))
-        self.assertTrue(branch.has_stored_uncommitted())
-        branch._put_uncommitted(None)
-        self.assertFalse(branch.has_stored_uncommitted())
-
     def bind(self, branch, master):
         try:
             branch.bind(master)
@@ -1103,26 +1095,18 @@
         self.bind(branch, master)
         return branch, master
 
-    def test_has_stored_uncommitted_bound(self):
-        branch, master = self.make_bound()
-        self.assertFalse(branch.has_stored_uncommitted())
-        master._put_uncommitted(StringIO('hello'))
-        self.assertTrue(branch.has_stored_uncommitted())
-        master._put_uncommitted(None)
-        self.assertFalse(branch.has_stored_uncommitted())
-
     def test_store_uncommitted(self):
         branch = self.make_branch('b')
         creator = FakeShelfCreator()
-        self.assertFalse(branch.has_stored_uncommitted())
+        self.assertIs(None, branch.get_unshelver(None))
         branch.store_uncommitted(creator)
         self.assertEqual('hello', branch._get_uncommitted().read())
 
     def test_store_uncommitted_bound(self):
         branch, master = self.make_bound()
         creator = FakeShelfCreator()
-        self.assertFalse(branch.has_stored_uncommitted())
-        self.assertFalse(master.has_stored_uncommitted())
+        self.assertIs(None, branch.get_unshelver(None))
+        self.assertIs(None, master.get_unshelver(None))
         branch.store_uncommitted(creator)
         self.assertEqual('hello', master._get_uncommitted().read())
 
@@ -1136,7 +1120,7 @@
         branch = self.make_branch('b')
         branch._put_uncommitted(StringIO('hello'))
         branch.store_uncommitted(None)
-        self.assertFalse(branch.has_stored_uncommitted())
+        self.assertIs(None, branch.get_unshelver(None))
 
     def test_get_unshelver(self):
         tree = self.make_branch_and_tree('tree')

=== modified file 'bzrlib/tests/test_workingtree.py'
--- bzrlib/tests/test_workingtree.py	2012-07-18 20:06:21 +0000
+++ bzrlib/tests/test_workingtree.py	2012-07-19 15:44:55 +0000
@@ -515,13 +515,13 @@
         tree = self.make_branch_and_tree('tree')
         tree.commit('get root in there')
         tree.store_uncommitted()
-        self.assertFalse(tree.branch.has_stored_uncommitted())
+        self.assertIs(None, tree.branch.get_unshelver(tree))
 
     def test_restore_uncommitted(self):
         with write_locked(self.store_uncommitted()) as tree:
             tree.restore_uncommitted()
             self.assertPathExists('tree/file')
-            self.assertFalse(tree.branch.has_stored_uncommitted())
+            self.assertIs(None, tree.branch.get_unshelver(tree))
 
     def test_restore_uncommitted_none(self):
         tree = self.make_branch_and_tree('tree')

